@@ -89,7 +89,6 @@ class AB_Base:
                     self.kwargs.get("search_complex", None) is not None:
 
                 # I searched for and found (or not) a result
-                self.logger.debug("Doing a Search")
                 try:
                     self.id = self.search()
                 except Exception as error_in_search:
@@ -210,7 +209,7 @@ class AB_Base:
                     found_item = potential
                     break
             elif self.kwargs.get("search_complex", None) is not None:
-                self.logger.debug("Doing Complex Search".format(self.kwargs["search_complex"]))
+                self.logger.debug("Doing Complex Search: {}".format(potential))
                 all_passed = True
                 for k, v in self.kwargs["search_complex"].items():
                     compare_value = potential.get("k", None)
@@ -226,6 +225,7 @@ class AB_Base:
                             # This one passed Continue to check the other items in search_complex
                             pass
                         else:
+                            self.logger.debug("{} {} != {}".format(k, compare_value, v.id))
                             all_passed = False
                             break
                     else:
@@ -233,6 +233,7 @@ class AB_Base:
                             # This one Passed Continue to Check the other items in search_complex
                             pass
                         else:
+                            self.logger.debug("{} {} != {}".format(k, compare_value, v))
                             all_passed = False
                             break
 
