@@ -20,7 +20,7 @@ class AB_Continous_Monitoring_Monitor_Results(abobjs.AB_Base):
     _fileable_type = "ContinuousMonitoringMonitorResult"
 
     _uid_field = None
-    _name_field = None
+    _name_field = "summary"
 
     def __init__(self, id=None, api_info=None, **kwargs):
 
