@@ -14,7 +14,7 @@ class AB_Continous_Monitoring_Monitors(abobjs.AB_Base):
 
     _endpoint = "/api/v1/continuous_monitoring_monitors"
     _single = ".continuous_monitoring_monitors[0]"
-    _name = "continuous_monitoring_monitors"
+    _name = "continuous_monitoring_monitor"
 
     _uid_field = None
 
